@@ -147,6 +147,9 @@ class WeixinMsg(object):
         return {}
 
     def reply(self, username=None, type='text', sender=None, **kwargs):
+        print("reply: username: %s, type: %s, sender: %s, kwargs: %s" %
+              (username, type, sender, kwargs))
+
         if not username:
             raise RuntimeError("username is missing")
         sender = sender or self.sender
